package com.zhilian.online;

import com.zhilian.common.security.annotation.EnableCustomConfig;
import com.zhilian.common.security.annotation.EnableMyFeignClients;
import com.zhilian.common.swagger.annotation.EnableCustomSwagger2;
import com.zhilian.online.controller.OnlineLoadCenterController;
import com.zhilian.online.domain.EcsInstance;
import com.zhilian.online.domain.req.EcsCreateReq;
import com.zhilian.online.uitls.AliyunOpenAPIUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import com.aliyun.ecs20140526.models.RunInstancesRequest;

import java.util.List;

/**
 * @version:
 * @Author: LiYuan
 * @description: 智联车辆上线服务启动类
 * @date: 2024/3/29  20:36
 */
@EnableCustomConfig
@EnableCustomSwagger2
@EnableMyFeignClients
@SpringBootApplication
@Slf4j
public class ZhiLianOnlineApplication implements ApplicationRunner {
    @Autowired
    private AliyunOpenAPIUtils aliyunOpenAPIUtils;

    public static void main(String[] args) {
        SpringApplication.run(ZhiLianOnlineApplication.class, args);
    }

    @Override
    public void run(ApplicationArguments args) throws Exception {
        log.info("项目启动,调用创建实例方法");
        RunInstancesRequest.RunInstancesRequestSystemDisk systemDisk = new RunInstancesRequest.RunInstancesRequestSystemDisk();
        systemDisk = systemDisk.setSize("20").setCategory("cloud_efficiency");
        EcsCreateReq ecs = EcsCreateReq.builder()
                .regionId("cn-zhangjiakou")
                .imageId("m-8vbfx0e48cekro0f13bx")
                .instanceType("ecs.t6-c1m1.large")
                .securityGroupId("sg-8vb49jd1c1lsa3akwo02")
                .vSwitchId("vsw-8vb0krtyfdmb27nhcmzc2")
                .instanceName("gather-node")
                .internetMaxBandwidthIn(80)
                .internetMaxBandwidthOut(10)
                .uniqueSuffix(true)
                .password("142730.Ly")
                .zoneId("cn-zhangjiakou-c")
                .internetChargeType("PayByTraffic")
                .systemDiskSize("20")
                .systemDickCategory("cloud_efficiency")
                .amount(1)
                .minAmount(1)
                .periodUnit("Week")
                .period(1)
                .instanceChargeType("PostPaid")
//                .privateIpAddress("10.10.27.1")
                .build();
        List<String> instance = aliyunOpenAPIUtils.createInstance(ecs);

        List<EcsInstance> ecsInstances = aliyunOpenAPIUtils.queryEcsInstances(instance);
        log.info("创建的实例信息为{}" , ecsInstances);
    }
}
