package com.zhilian.online.config;

import com.aliyun.ecs20140526.Client;
import com.aliyun.teaopenapi.models.Config;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.stereotype.Component;
import com.aliyun.ecs20140526.Client;
import com.aliyun.teaopenapi.models.Config;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.config
 * @Author: LiYuan
 * @CreateTime: 2024-04-12  14:43
 * @Description: 阿里云Ecs服务账号配置
 * @Version: 1.0
 */
@Configuration
@ConfigurationProperties("aliyun.ecs")
@Data
@Slf4j
public class AliyunEcsConfig {

    /**
     * 令牌账号
     */
    private String accessKeyId;

    /**
     * 令牌密码
     */
    private String accessKeySecret;

    /**
     * 阿里云端点地址
     */
    private String endpoint;

    /**
     * 地域
     */
    private String regionId;

    /**
     * 使用AK&SK初始化账号Client
     * @return Client
     * @throws Exception
     */
    @Bean()
    public Client createClient() throws Exception {
        // 工程代码泄露可能会导致 AccessKey 泄露，并威胁账号下所有资源的安全性。以下代码示例仅供参考。
        // 建议使用更安全的 STS 方式，更多鉴权访问方式请参见：https://help.aliyun.com/document_detail/378657.html。
        Config  config = new Config()
                // 必填，请确保代码运行环境设置了环境变量 ALIBABA_CLOUD_ACCESS_KEY_ID。
                .setAccessKeyId(accessKeyId)
                // 必填，请确保代码运行环境设置了环境变量 ALIBABA_CLOUD_ACCESS_KEY_SECRET。
                .setAccessKeySecret(accessKeySecret)
                .setRegionId(regionId);
        // Endpoint 请参考 https://api.aliyun.com/product/Ecs
        config.endpoint = endpoint;
        Client aliyunClient = new Client(config);
        return aliyunClient;
    }

}
