package com.zhilian.online.consumer;

import com.alibaba.fastjson2.JSONObject;
import com.google.gson.JsonObject;
import com.zhilian.common.core.constant.Constants;
import com.zhilian.common.redis.service.RedisService;
import com.zhilian.online.constans.OnlineConstants;
import com.zhilian.online.domain.model.GatewayNodeInfo;
import com.zhilian.online.load.cache.GatewayNodeInfoCache;
import com.zhilian.online.load.cache.GatewayNodeWeightCache;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.net.HttpURLConnection;
import java.net.URL;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.consumer
 * @Author: LiYuan
 * @CreateTime: 2024-03-30  19:57
 * @Description: 监听死信队列消费者
 * @Version: 1.0
 */
@Component
@Slf4j
public class DeadQueueConsumer {

    /**
     * redis服务
     */
    @Autowired
    private RedisService redisService;

    @Autowired
    private GatewayNodeInfoCache gatewayNodeInfoCache;

    @Autowired
    private GatewayNodeWeightCache gatewayNodeWeightCache;


    /**
     * 消费死信队列中的消息,确保车辆上线成功
     * 向节点地址的fluxMQ发送http请求,通过响应码来确定节点是否成功上线
     */
//    @RabbitListener(queues = RabbitConfig.DEAD_QUEUE_NAME)
    public void SecureOnline(String gatherMsg) {
        log.info("开始检查节点{}的上线状态......", gatherMsg);
        GatewayNodeInfo gatewayNodeInfo = JSONObject.parseObject(gatherMsg, GatewayNodeInfo.class);

        String ipAddress = "";
        HttpURLConnection connection = null;
        try {
            ipAddress = OnlineConstants.HTTP_PREFIX + ipAddress + OnlineConstants.FLUXMQ_INFO_URL;
            URL url = new URL(ipAddress);
            connection = (HttpURLConnection)url.openConnection();
            connection.setRequestMethod("GET");

            int responseCode = connection.getResponseCode();
            if (Constants.SUCCESS  == responseCode){
                log.info("节点上线成功");
            }
            if (Constants.FAIL == responseCode){
                log.error("节点{}上线失败",gatherMsg);
                //删除节点数据
                gatewayNodeInfoCache.remove(gatewayNodeInfo.getNodeId());
                //上线失败需要将该节点的负载均衡缓存删除
                gatewayNodeWeightCache.remove(gatewayNodeInfo);
            }
        } catch (Exception e) {
            log.error("节点上线失败{}",e.getMessage());
            e.printStackTrace();
        }finally {
            if (null != connection){
                connection.disconnect();
            }
        }
    }

//    /**
//     * 确定车辆上线成功
//     * @param vin
//     */
//    @RabbitListener(queues = RabbitConfig.DEAD_QUEUE_FOR_CAR)
//    public void checkedConnectionOfVehicle(String vin){
//        Set<Object> cacheSet = redisService.getCacheSet(OnlineConstants.ONLINE_VEHICLE);
//        List<String> list= cacheSet.stream().map(item -> {
//            return String.valueOf(item);
//        }).collect(Collectors.toList());
//        if (list.contains(vin)){
//            log.info("{}车辆上线成功",vin);
//        }else {
//            log.error("{}车辆上线失败",vin);
//
//
//            String clientId = (String) redisService.getCacheObject(OnlineConstants.ONLINE_VEHICLE + vin);
//
//            redisService.deleteObject(OnlineConstants.ONLINE_VEHICLE+vin);
//            redisService.getCacheZsetMin(OnlineConstants.GATHER_LOAD_CONTROL);
//            redisService.incrementScore(OnlineConstants.GATHER_LOAD_CONTROL + clientId ,gather,-1.0);
//        }
//    }

}
