package com.zhilian.online.domain;

import lombok.*;

import java.util.List;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.domain
 * @Author: LiYuan
 * @CreateTime: 2024-04-12  15:01
 * @Description: 阿里云ECS服务器实体类
 * @Version: 1.0
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@ToString
public class EcsInstance {

    /**
     * 实例创建时间。以 ISO 8601 为标准，并使用 UTC+0 时间，格式为 yyyy-MM-ddTHH:mmZ
     */
    private String creationTime;

    /**
     * 实例序列号
     */
    private String serialNumber;

    /**
     * 实例状态
     */
    private String status;

    /**
     * 部署集ID
     */
    private String deploymentSetId;

    /**
     * 密钥对名称。
     */
    private String keyPairName;

    /**
     * 按量实例的竞价策略。可能值:
     * NoSpot：正常按量付费实例。
     * SpotWithPriceLimit：设置上限价格的抢占式实例。
     * SpotAsPriceGo：系统自动出价
     */
    private String spotStrategy;

    /**
     * 实例是否支持挂载磁盘。
     */
    private Boolean deviceAvailable;

    /**
     * 实例挂载的本地存储容量。单位：GiB
     */
    private Long localStorageCapacity;

    /**
     * 实例描述
     */
    private String description;

    /**
     * 抢占式实例的保留时长，单位为小时。可能值：
     * 1：创建后阿里云会保证实例运行 1 小时不会被自动释放；超过 1 小时后，系统会自动比较出价与市场价格、检查资源库存，来决定实例的持有和回收。
     * 0：创建后，阿里云不保证实例运行 1 小时，系统会自动比较出价与市场价格、检查资源库存，来决定实例的持有和回收。
     */
    private Integer spotDuration;

    /**
     * 实例网络类型。可能值：
     * classic：经典网络。
     * vpc：专有网络 VPC。
     */
    private String instanceNetworkType;

    /**
     *  实例名称
     */
    private String instanceName;

    /**
     *  实例ID
     */
    private String instanceId;

    /**
     * 实例操作系统的英文名称
     */
    private String osNameEn;

    /**
     *实例所属的 HPC 集群 ID。
     */
    private String hpcClusterId;

    /**
     * 实例的每小时最高价格。支持最大 3 位小数，参数 SpotStrategy=SpotWithPriceLimit 时，该参数生效。
     */
    private Number spotPriceLimit;

    /**
     * 内存大小，单位为 MiB。
     */
    private Integer memory;

    /**
     * 实例的操作系统名称
     */
    private String osName;

    /**
     * ECS 实例绑定部署集分散部署时，实例在部署集中的分组位置。
     */
    private String deploymentSetGroupNo;

    /**
     * 实例运行的镜像 ID。
     */
    private String imageId;

    /**
     * 实例的 GPU 类型。
     */
    private String gpuSpec;

    /**
     * 实例释放保护属性，指定是否支持通过控制台或 API（DeleteInstance）释放实例。
     * true：已开启实例释放保护。
     * false：未开启实例释放保护。
     */
    private Boolean deletionProtection;

    /**
     * 实例停机后是否继续收费。可能值：
     * KeepCharging：停机后继续收费，为您继续保留库存资源。
     * StopCharging：停机后不收费。停机后，我们释放实例对应的资源，例如 vCPU、内存和公网 IP 等资源。重启是否成功依赖于当前地域中是否仍有资源库存。
     * Not-applicable：本实例不支持停机不收费功能。
     */
    private String stoppedMode;

    /**
     * 实例规格附带的 GPU 数量。
     */
    private Integer gpuAmount;

    /**
     * 实例主机名
     */
    private String hostName;

    /**
     * 公网出带宽最大值，单位：Mbit/s
     */
    private Integer internetMaxBandwidthOut;

    /**
     * 公网入带宽最大值，单位：Mbit/s
     */
    private Integer internetMaxBandwidthIn;

    /**
     * 实例规格
     */
    private String instanceType;

    /**
     * 实例的计费方式。可能值：
     * PrePaid：包年包月。
     * PostPaid：按量付费。
     */
    private String instanceChargeType;

    /**
     * 实例所属地域 ID。
     */
    private String regionId;

    /**
     * 是否为 I/O 优化型实例。
     */
    private Boolean ioOptimized;

    /**
     * 实例最近一次的启动时间。以 ISO 8601 为标准，并使用 UTC+0 时间，格式为 yyyy-MM-ddTHH:mmZ
     */
    private String startTime;

    /**
     * vCPU 数
     */
    private Integer cpu;

    /**
     * 实例挂载的本地存储数量。
     */
    private Integer localStorageAmount;

    /**
     * 过期时间。以 ISO 8601 为标准，并使用 UTC+0 时间，格式为 yyyy-MM-ddTHH:mmZ
     */
    private String expiredTime;

    /**
     * 实例所属可用区。
     */
    private String zoneId;

    /**
     * 实例是否可以回收。
     */
    private Boolean recyclable;

    /**
     * 突发性能实例的运行模式。可能值：
     * Standard：标准模式。有关实例性能的更多信息，请参见什么是突发性能实例中的性能约束模式章节。
     * Unlimited：无性能约束模式，有关实例性能的更多信息，请参见什么是突发性能实例中的无性能约束模式章节。
     */
    private String creditSpecification;

    /**
     * 实例规格族。
     */
    private String instanceTypeFamily;

    /**
     * 实例的操作系统类型，分为 Windows Server 和 Linux 两种。可能值：
     * windows。
     * linux。
     */
    private String osType;

    /**
     * 公网IP地址
     */
    private String publicIpAddress;

    /**
     * 内网IP地址
     */
    private String privateIpAddress;

    /**
     * 专有网络ID
     */
    private String vpcId;

    /**
     * 安全组ID
     */
    private List<String> securityGroupIds;


}
