package com.zhilian.online.domain.req;

import lombok.*;

import javax.validation.constraints.NotBlank;
import java.util.List;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.domain.req
 * @Author: LiYuan
 * @CreateTime: 2024-04-12  15:37
 * @Description: 阿里云openAPI查询实例请求
 * @Version: 1.0
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@ToString
@Builder
public class EcsQueryReq {

    /**
     * 实例所属地域 ID。
     */
    @NotBlank
    private String regionId;

    /**
     * 专有网络ID
     */
    private String vpcId;

    /**
     * 交换机ID
     */
    private String vSwitchId;

    /**
     * 可用区ID。
     */
    private String zoneId;

    /**
     * 实例网络类型。可能值：
     * classic：经典网络。
     * vpc：专有网络 VPC。
     */
    private String instanceNetworkType;

    /**
     * 安全组ID
     */
    private String securityGroupId;

    /**
     * 实例ID  ["i-bp67acfmxazb4p****", "i-bp67acfmxazb4p****", … "i-bp67acfmxazb4p****"]
     */
    private List<String> instanceIds;

    /**
     * 页码
     */
    private Integer pageNumber = 1;

    /**
     * 每页条数
     */
    private Integer pageSize = 10;

    /**
     * 内网IP地址集 ["172.16.1.1", "172.16.2.1", … "172.16.10.1"]
     */
    private String privateIpAddresses;

    /**
     * 内网IP地址集 ["172.16.1.1", "172.16.2.1", … "172.16.10.1"]
     */
    private String publicIpAddresses;

    /**
     * 实例名称，支持使用通配符*进行模糊搜索。
     */
    private String instanceName;

    /**
     * 镜像ID
     */
    private String imageId;

    /**
     * 实例状态
     */
    private String status;

    /**
     * 实例规格
     */
    private String instanceType;

}
