package com.zhilian.online.load.cache;

import com.zhilian.common.redis.service.RedisService;
import com.zhilian.online.load.abs.GatewayCacheAbs;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.load.cache
 * @Author: LiYuan
 * @CreateTime: 2024-04-18  19:11
 * @Description: 加权轮询的100个节点IP 为之后车辆上线取用
 * @Version: 1.0
 */
@Component
public class GatewayLoadNodeCache extends GatewayCacheAbs<String> {



    private final static String gatewayLoadNodeKey = "node";

    @Override
    public String getPre() {
        return "gateway:load:";
    }

    /**
     * @description: 存放
     * @author: LiYuan
     * @param: nodeList
     * @return: void
     **/
    public void put(List<String> nodeList) {
        redisService.deleteObject(encode(gatewayLoadNodeKey));
        redisService.setCacheList(encode(gatewayLoadNodeKey), nodeList);
    }

    /**
     * @description: 获取所有负载节点
     * @author: LiYuan
     * @param: null
     * @return: List<String>
     **/
    public List<String> get() {
        return redisService.getCacheList(encode(gatewayLoadNodeKey));
    }


    /**
     * @description: 通过下标获取节点
     * @author: LiYuan
     * @param: index 下标
     * @return: String node 节点
     **/
    public String getByIndex(Long index){
        if (null == index || index > 100){
            throw new RuntimeException("下标违法，不在[0-100]内");
        }
        return redisService.getcacheListValue(encode(gatewayLoadNodeKey),index);
    }


}
