package com.zhilian.online.load.cache;

import com.zhilian.online.load.abs.GatewayCacheAbs;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.load.cache
 * @Author: LiYuan
 * @CreateTime: 2024-04-18  19:34
 * @Description: 网关负载自增序列
 * @Version: 1.0
 */
@Component
public class GatewayLoadSeriesCache extends GatewayCacheAbs<String> {

    private final static String gatewayLoadSeriesKey = "series";


    @Override
    public String getPre() {
        return "gateway:load:";
    }

    /**
     * @description: 创建Bean后初始化自增序列
     * @author: LiYuan
     * @param:
     * @return:
     **/
    @PostConstruct
    public void init() {
        redisService.setCacheObject(encode(gatewayLoadSeriesKey), 0);
    }


    /**
     * @description: 获取自增序列的值
     * @author: LiYuan
     * @param:
     * @return: Long
     **/
    public Long incrementAndGet() {
        return redisService.increment(encode(gatewayLoadSeriesKey), 1L);
    }


    /**
     * @description: 获取当前序列的值
     * @author: LiYuan
     * @param:
     * @return:
     **/
    public Long get() {
        return redisService.getCacheObject(encode(gatewayLoadSeriesKey));
    }

    /**
     * @description: 重置序列中的值
     * @author: LiYuan
     * @param:
     * @return:
     **/
    public void reset() {
        this.init();
    }


}
