package com.zhilian.online.load.cache;

import com.zhilian.online.load.abs.GatewayCacheAbs;

import java.util.*;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.load.cache
 * @Author: LiYuan
 * @CreateTime: 2024-04-19  19:42
 * @Description: 节点负载的车辆数据操作
 * @Version: 1.0
 */
public class GatewayNodeCarsCache extends GatewayCacheAbs<String> {
    @Override
    public String getPre() {
        return "gateway:node:cars";
    }

    /**
     * @description: 车辆上线添加数据
     * @author: LiYuan
     * @param: String nodeId, String vin
     * @return: void
     **/
    public void put(String nodeId, String vin) {
        redisService.setCacheSet(encode(nodeId), vin);
    }


    /**
     * @description: 根据节点获取其负载车辆vin列表
     * @author: LiYuan
     * @param: String nodeId
     * @return: void
     **/
    public List<String> get(String nodeId) {
        Set<String> res = redisService.getCacheSet(encode(nodeId));
        return res.stream().map(String::valueOf).toList();
    }

    /**
     * @description: 删除下线车辆
     * @author: LiYuan
     * @param: String nodeId, String vin
     * @return: void
     **/
    public void remove(String nodeId, String vin) {
        redisService.deleteCacheSetValue(encode(nodeId), vin);
    }


}
