package com.zhilian.online.load.cache;

import com.zhilian.online.domain.model.GatewayNodeInfo;
import com.zhilian.online.load.abs.GatewayCacheAbs;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.load.cache
 * @Author: LiYuan
 * @CreateTime: 2024-04-18  19:44
 * @Description: 网关负载中心节点数据缓存  String  key(节点ID) + 节点 对象
 * @Version: 1.0
 */
@Component
public class GatewayNodeInfoCache extends GatewayCacheAbs<String > {


    @Override
    public String getPre() {
        return "gateway:node:info:";
    }

    /**
     * @description: 增加节点数据
     * @author: LiYuan
     * @param: GatewayNodeInfo 节点数据
     * @return: 
     **/
    public void put(GatewayNodeInfo gatewayNodeInfo){
        redisService.setCacheObject(encode(gatewayNodeInfo.getNodeId()),gatewayNodeInfo);
    }

    /**
     * @description: 获取节点缓存数据
     * @author: LiYuan
     * @param: nodeId 节点Id
     * @return:
     **/
    public GatewayNodeInfo get(String nodeId){
        return redisService.getCacheObject(encode(nodeId));
    }


    /**
     * @description: 获取所有节点数据
     * @author: LiYuan
     * @param:
     * @return:
     **/
    public List<GatewayNodeInfo> get(){
        return redisService.getCacheObject(encode(getPre()));
    }

    /**
     * @description: 删除网关节点
     * @author: LiYuan
     * @param:
     * @return: 
     **/
    public void remove(String nodeId){
        redisService.deleteObject(encode(nodeId));
    }


}
