package com.zhilian.online.load.cache;

import com.zhilian.online.domain.model.GatewayNodeInfo;
import com.zhilian.online.load.abs.GatewayCacheAbs;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.load.cache
 * @Author: LiYuan
 * @CreateTime: 2024-04-18  20:03
 * @Description: 节点权重数据
 * @Version: 1.0
 */
@Component
public class GatewayNodeWeightCache extends GatewayCacheAbs<String > {

    private final static String gatewayNodeLoadKey = "weight";

    @Override
    public String getPre() {
        return "gateway:node:";
    }


    /**
     * @description: 获取所有Zset集合
     * @author: LiYuan
     * @param: void
     * @return: Map<Object,Double>
     **/
    public Map<Object,Double> get(){
        return redisService.getCacheObject(encode(gatewayNodeLoadKey));
    }

    /**
     * @description: 获取指定节点分数
     * @author: LiYuan
     * @param:  gatewayNodeInfo
     * @return: score
     **/
    public Double get(GatewayNodeInfo gatewayNodeInfo){
        return redisService.getCacheZsetScore(encode(gatewayNodeLoadKey),gatewayNodeInfo);
    }

    /**
     * @description:
     * @author: LiYuan
     * @param:
     * @return:
     **/
    public void put(GatewayNodeInfo gatewayNodeInfo){
        redisService.setCacheZsetValue(encode(gatewayNodeLoadKey),gatewayNodeInfo,0.0);
    }

    /**
     * @description:
     * @author: LiYuan
     * @param:
     * @return:
     **/
    public void increment(GatewayNodeInfo gatewayNodeInfo,Double score){
        redisService.incrementScore(encode(gatewayNodeLoadKey),gatewayNodeInfo,score);
    }


    /**
     * @description:
     * @author: LiYuan
     * @param:
     * @return:
     **/
    public void remove(GatewayNodeInfo gatewayNodeInfo) {
        redisService.deleteCacheZsetValue(encode(gatewayNodeLoadKey),gatewayNodeInfo);
    }
}
