package com.zhilian.online.uitls;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.zhilian.online.constans.OnlineConstants;
import lombok.extern.slf4j.Slf4j;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import org.springframework.stereotype.Component;
import org.springframework.test.web.servlet.RequestBuilder;

import java.io.IOException;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.uitls
 * @Author: LiYuan
 * @CreateTime: 2024-04-17  21:41
 * @Description: mqtt工具类
 * @Version: 1.0
 */
@Component
@Slf4j
public class MqttUtil {

    /**
     * @description: 通过ip地址调用mqtt服务获取fluxmq的负载量
     * @author: LiYuan
     * @param: ipAddress
     * @return: Integer
     **/
    public Integer getLoadInfoByIp(String ipAddress) {

        int num = 0;

        String URL = OnlineConstants.HTTP_PREFIX + ipAddress + OnlineConstants.FLUXMQ_INFO_URL;

        OkHttpClient client = new OkHttpClient();
        Request build = new Request.Builder()
                .url(URL)
                .get()
                .addHeader("User-Agent","Apifox/1.0.0(https://apifox.com)")
                .addHeader("AccessToken","")
                .build();

        try {
            Response response = client.newCall(build).execute();
            JSONArray jsonArray = JSONArray.parseArray(response.body().string());
            JSONObject jsonObject = jsonArray.getJSONObject(0);

            //获取mqttInfo对象的值
            JSONObject mqttInfo = jsonObject.getJSONObject("mqttInfo");

            //获取fluxmq链接数
            num = mqttInfo.getIntValue("connectSize");

            log.info("{}的fluxMq链接数为：{}",ipAddress,num);

        } catch (IOException e) {
           log.error(e.getMessage());
        }

        return num;

    }

}
